isDark property
bool
get
isDark
Returns true if this color is perceived as dark.
Implementation
bool get isDark => !isLight;
Returns true if this color is perceived as dark.
bool get isDark => !isLight;