isLight property
bool
get
isLight
Returns true if this color is perceived as light.
Uses the WCAG relative luminance formula.
Implementation
bool get isLight => luminance > 0.179;
Returns true if this color is perceived as light.
Uses the WCAG relative luminance formula.
bool get isLight => luminance > 0.179;