daysUntilEndOfYear method
Returns the number of days until the end of the year.
Implementation
int daysUntilEndOfYear() => endOfYear.difference(startOfDay).inDays;
Returns the number of days until the end of the year.
int daysUntilEndOfYear() => endOfYear.difference(startOfDay).inDays;