isFuture property
bool
get
isFuture
Returns true if this date is in the future.
Implementation
bool get isFuture => isAfter(DateTime.now());
Returns true if this date is in the future.
bool get isFuture => isAfter(DateTime.now());