isPast property
bool
get
isPast
Returns true if this date is in the past.
Implementation
bool get isPast => isBefore(DateTime.now());
Returns true if this date is in the past.
bool get isPast => isBefore(DateTime.now());