inWeeks property
int
get
inWeeks
Returns the number of whole weeks in this duration.
Implementation
int get inWeeks => inDays ~/ 7;
Returns the number of whole weeks in this duration.
int get inWeeks => inDays ~/ 7;