associateWith<V> method
Returns a map of each element to the result of value.
Implementation
Map<T, V> associateWith<V>(V Function(T) value) =>
{for (final e in this) e: value(e)};
Returns a map of each element to the result of value.
Map<T, V> associateWith<V>(V Function(T) value) =>
{for (final e in this) e: value(e)};