clearAndAddAll method
Clears this list and adds all elements from items.
Implementation
void clearAndAddAll(List<T> items) {
clear();
addAll(items);
}
Clears this list and adds all elements from items.
void clearAndAddAll(List<T> items) {
clear();
addAll(items);
}