removeFirst method
void
removeFirst(
- T item
Removes the first occurrence of item from the list.
Implementation
void removeFirst(T item) {
final i = indexOf(item);
if (i != -1) removeAt(i);
}
Removes the first occurrence of item from the list.
void removeFirst(T item) {
final i = indexOf(item);
if (i != -1) removeAt(i);
}