second property
T?
get
second
Returns the second element, or null if the list has fewer than 2 items.
Implementation
T? get second => length >= 2 ? this[1] : null;
Returns the second element, or null if the list has fewer than 2 items.
T? get second => length >= 2 ? this[1] : null;