third property
T?
get
third
Returns the third element, or null if the list has fewer than 3 items.
Implementation
T? get third => length >= 3 ? this[2] : null;
Returns the third element, or null if the list has fewer than 3 items.
T? get third => length >= 3 ? this[2] : null;