contains method
Returns true if this map contains key with exactly value.
Implementation
bool contains(K key, V value) => containsKey(key) && this[key] == value;
Returns true if this map contains key with exactly value.
bool contains(K key, V value) => containsKey(key) && this[key] == value;