mapValues<V2> method
Returns a new map with values transformed by f.
Implementation
Map<K, V2> mapValues<V2>(V2 Function(V value) f) =>
{for (final e in entries) e.key: f(e.value)};
Returns a new map with values transformed by f.
Map<K, V2> mapValues<V2>(V2 Function(V value) f) =>
{for (final e in entries) e.key: f(e.value)};