shift method
Removes and returns the first entry in the map.
Implementation
MapEntry<K, V> shift() {
final entry = entries.first;
remove(entry.key);
return entry;
}
Removes and returns the first entry in the map.
MapEntry<K, V> shift() {
final entry = entries.first;
remove(entry.key);
return entry;
}