digitCount property
int
get
digitCount
Returns the number of digits in the integer part.
Implementation
int get digitCount => toInt().abs().toString().length;
Returns the number of digits in the integer part.
int get digitCount => toInt().abs().toString().length;