isInteger property
bool
get
isInteger
Returns true if this number has no fractional part.
Implementation
bool get isInteger => this == truncate();
Returns true if this number has no fractional part.
bool get isInteger => this == truncate();