isAlpha property
bool
get
isAlpha
Returns true if this string contains only alphabetic characters.
Implementation
bool get isAlpha => isNotEmpty && RegExp(r'^[a-zA-Z]+$').hasMatch(this);
Returns true if this string contains only alphabetic characters.
bool get isAlpha => isNotEmpty && RegExp(r'^[a-zA-Z]+$').hasMatch(this);