uncapitalize method
Returns a new string with the first character in lower case.
'Hello'.uncapitalize() // 'hello'
Implementation
String uncapitalize() {
if (isEmpty) return '';
return '${this[0].toLowerCase()}${substring(1)}';
}
Returns a new string with the first character in lower case.
'Hello'.uncapitalize() // 'hello'
String uncapitalize() {
if (isEmpty) return '';
return '${this[0].toLowerCase()}${substring(1)}';
}