StringUtilsNullable extension

Null-safe extensions on String?.

on

Properties

isNullOrBlank bool

Available on String?, provided by the StringUtilsNullable extension

Returns true if this string is null, empty, or contains only whitespace.
no setter
isNullOrEmpty bool

Available on String?, provided by the StringUtilsNullable extension

Returns true if this string is null or empty.
no setter
orEmpty String

Available on String?, provided by the StringUtilsNullable extension

Returns this string, or '' if null.
no setter

Methods

orDefault(String fallback) String

Available on String?, provided by the StringUtilsNullable extension

Returns this string, or fallback if null or empty.