isNullOrBlank property
bool
get
isNullOrBlank
Returns true if this string is null, empty, or contains only whitespace.
Implementation
bool get isNullOrBlank => this == null || this!.trim().isEmpty;
Returns true if this string is null, empty, or contains only whitespace.
bool get isNullOrBlank => this == null || this!.trim().isEmpty;