UriUtils extension

Extensions on Uri for real-world utility operations.

on

Properties

hasQueryParams bool

Available on Uri, provided by the UriUtils extension

Returns true if this URI has at least one query parameter.
no setter
isAbsolute bool

Available on Uri, provided by the UriUtils extension

Returns true if this URI is an absolute URL (has scheme + host).
no setter
isSecure bool

Available on Uri, provided by the UriUtils extension

Returns true if this URI uses https.
no setter

Methods

appendPath(String segment) Uri

Available on Uri, provided by the UriUtils extension

Appends a segment to the URI path.
removeQueryParam(String key) Uri

Available on Uri, provided by the UriUtils extension

Returns a new Uri with key removed from the query string.
withQueryParam(String key, String value) Uri

Available on Uri, provided by the UriUtils extension

Returns a new Uri with key=value added (or replaced) in the query.
withQueryParams(Map<String, String> params) Uri

Available on Uri, provided by the UriUtils extension

Returns a new Uri with all params merged into the query string.